/*
	ProWesS, PROGS Windowing System

	dynamic configurator program for ProWesS

	(c) PROGS, Professional & Graphical Software
	written by Joachim Van der Auwera
	started 04 October 1995
*/

#include "io.h"
#include "str.h"
#include "dir.h"

#include "ProWesS.h"

static char info[]={"This program allow directory structures to\n"
					"be copied. All subdirectories of the given\n"
					"source directory will be subdirectories of\n"
					"the destination."};

typedef struct {
	PWObject source,dest;
	} Global;

Error copy(PWObject object)
{
	Global *g;
	char source[IO_MAXFULLNAME];
	char dest[IO_MAXFULLNAME];
	char newdir[IO_MAXFULLNAME];
	DirIterator it;
	FileInfo fi;
	Error err;

	PWQuery(object,PW_GLOBAL_AUXILIARY,&g);

	PWChange(g->source,PW_EDLINE_GET,IO_MAXFULLNAME,source,NULL);
	PWChange(g->dest,PW_EDLINE_GET,IO_MAXFULLNAME,dest,NULL);

	if (dest[strlen(dest)-1]!='_')
		STRAppendSafe("_",dest,IO_MAXFULLNAME);

	if (!DIRSubOpen(source,TRUE,&it))
	{
		while(!DIRSubNext(it,&fi))
		{
			STRCopy(dest,newdir);
			STRAppendSafe(fi.name,newdir,IO_MAXFULLNAME);
			err=IOMakeDirectory(newdir);
			if (err && err!=ERR_FEX) return err;
		}
		DIRSubClose(it);
	}



	return ERR_OK;
}

void init()
{
	PWObject obj;
	Global g;

	PWCreate(NULL,&obj,PW_TYPE_OUTLINE,
				PW_OUTLINE_SLEEP,
				PW_OUTLINE_QUIT,
				PW_OUTLINE_QUIT_KEYPRESS, 27,
				PW_WINDOW_NOSCALE,
				PW_OUTLINE_ACTION_DO, copy,
				PW_GLOBAL_AUXILIARY, &g,
				NULL);
	PWCreate(obj,NULL,PW_TYPE_INFOSTRING,
				PW_INFOSTRING_TEXT, info,
				NULL);
	PWCreate(obj,&g.source,PW_TYPE_EDLINE,
				PW_EDLINE_MAXLENGTH, IO_MAXFULLNAME,
				PW_EDLINE_EDLINE_AFTER, g.dest,
				NULL);
	PWCreate(obj,&g.dest,PW_TYPE_EDLINE,
				PW_EDLINE_MAXLENGTH, IO_MAXFULLNAME,
				PW_EDLINE_EDLINE_UP, g.source,
				NULL);
	PWChange(g.source,
				PW_EDLINE_EDLINE_AFTER, g.dest,
				PW_EDLINE_EDLINE_DOWN, g.dest,
				NULL);
	PWCreate(obj,NULL,PW_TYPE_LABEL,
				PW_POSITION_LEFT_OF, g.source,
				PW_SCALE_FACTOR, 0,
				PW_LABEL_TEXT, "source",
				NULL);
	PWCreate(obj,NULL,PW_TYPE_LABEL,
				PW_POSITION_LEFT_OF, g.dest,
				PW_SCALE_FACTOR, 0,
				PW_LABEL_TEXT, "destination",
				NULL);
								  
	PWActivate(obj);
}
